@@ -14,7 +14,7 @@ use base qw(Apache::Session);
 use Lemonldap::NG::Common::Apache::Session::Store;
 use Lemonldap::NG::Common::Apache::Session::Lock;
 
-our $VERSION = '1.4.0';
+our $VERSION = '1.4.8';
 
 sub _load {
     my $backend = shift;
@@ -154,7 +154,8 @@ sub get_key_from_all_sessions {
         return $backend->get_key_from_all_sessions(@_);
     }
     if ( $backend =~
-        /^Apache::Session::(MySQL|MySQL::NoLock|Postgres|Oracle|Sybase|Informix)$/ )
+/^Apache::Session::(MySQL|MySQL::NoLock|Postgres|Oracle|Sybase|Informix)$/
+      )
     {
         return $class->_dbiGKFAS( $1, @_ );
     }
@@ -320,6 +321,8 @@ sub _LDAPGKFAS {
         filter => '(objectClass=applicationProcess)',
         attrs  => [ 'cn', 'description' ],
     );
+    $ldap->unbind();
+    $ldap->disconect();
     Apache::Session::Store::LDAP->logError($msg) if ( $msg->code );
     my %res;
     foreach my $entry ( $msg->entries ) {
